@@ -1,4 +1,5 @@
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,8 +8,6 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_events
@@ -16,9 +15,11 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
+import aws_cdk.aws_s3_notifications
 import aws_cdk.aws_sns
+import aws_cdk.aws_sns_subscriptions
 import aws_cdk.aws_sqs
-import aws_cdk.cdk
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
